@@ -113,7 +113,13 @@ setMethod('posterior', signature(model = "BFlinearModel", index = "missing", dat
                        gibbs = TRUE, ...) 
     }else{
       # GLM
-      stop("GLM sampling not yet implemented.")
+      chains = nWayFormula(formula=formula, data = data, 
+                       dataTypes = dataTypes,
+                       rscaleFixed = rscaleFixed,
+                       rscaleRandom = rscaleRandom,
+                       rscaleCont = rscaleCont,
+                       iterations = iterations,
+                       gibbs = TRUE, ...)        
     }
     
     return(new("BFmcmc",chains, model = model, data = data))
@@ -154,4 +160,6 @@ as.matrix.BFmcmc <- function(x,...){
 
 as.data.frame.BFmcmc <- function(x, row.names=NULL,optional=FALSE,...){
   return(as.data.frame(S3Part(x)))
-}
\ No newline at end of file
+}
+
+
